@@ -11,15 +11,13 @@ def status(ssh, pkgs):
     installed = mcv.pip._status(out)
     return { p:installed.get(p) for p in pkgs }
 
-def _install(ssh, pkgs, sudo=False, verbose=False):
-    if not pkgs:
-        return True
-
-    cmd = [pip_cmd, 'install'] + pkgs
-
-    return mcv.remote.execute(ssh, cmd, sudo=sudo, verbose=verbose)
-
-def install(ssh, pkgs, sudo=False, verbose=False):
+def install(ssh, pkgs, sudo=False, verbose=False, upgrade=False):
     installed_packages = status(ssh, pkgs)
     pkgs_to_install = [p for p in pkgs if not installed_packages[p]]
-    return _install(ssh, pkgs_to_install, sudo=sudo, verbose=verbose)
+
+    cmd = mcv.pip._install_cmd(pkgs_to_install, upgrade=upgrade)
+
+    if cmd:
+        return mcv.remote.execute(ssh, cmd, sudo=sudo, verbose=verbose)
+    else:
+        return None
